#
# spec file for package libspiro
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum   1
Name:           libspiro
Version:        20221101
Release:        1.5
Summary:        A clothoid to bezier spline converter
License:        GPL-3.0-or-later
Group:          System/Libraries
URL:            https://github.com/fontforge/libspiro
Source0:        https://github.com/fontforge/libspiro/archive/%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libspiro contains routines which will convert an array of clothoid
spline control points into an equivalent set of bezier control points.

%package -n %{name}%{sonum}
Summary:        A clothoid to bezier spline converter
Group:          System/Libraries

%description -n %{name}%{sonum}
libspiro contains routines which will convert an array of clothoid
spline control points into an equivalent set of bezier control points.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}1 = %{version}
Requires:       glibc-devel

%description devel
This package contains all necessary include files and libraries needed
to compile and develop applications that use %{name}.

%prep
%setup -q

%build
autoreconf -i
automake --foreign -Wall
%configure --with-pic\
           --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{sonum} -p /sbin/ldconfig
%postun -n %{name}%{sonum} -p /sbin/ldconfig

%files -n %{name}%{sonum}
%license COPYING
%doc ChangeLog README*
%{_libdir}/lib*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_mandir}/man3/libspiro.3%{?ext_man}
%{_libdir}/pkgconfig/*.pc

%changelog
* Thu Dec  8 2022 Dirk Müller <dmueller@suse.com>
- update to 20221101:
  * Bugfix - removed forgotten if-then code used with scaling tests.
    Majority of users won't notice a difference since most FontForge
    fonts are created in the +x,+y quadrant. Users that might see a
    change/difference are users drawing only in the -x, -y quadrant.
  * Enhanced libspiro to allow closed-loop spiros starting with '['
    or 'a' by seeking the first available 'v', 'c', or 'o' as start,
    which may be found later in the spiro curve. This was the least
    modification needed to allow call-test10 or call-test11 to pass.
  * Due to confusion created when ppedit was also re-licensed as MIT
    APACHE and GPL2+, it's necessary to re-clarify libspiro is GPL3+.
    In summary, GPL can include MIT code, MIT code cannot accept GPL.
    Please note code not in ppedit like libspiro's java is GNU GPL2+.
    Please note that libspiro's improvements or patches are also GPL.
  * Thanks to orbea for bugfixes concerning linking and linker flags,
    and removing .libs from linker path (some linkers don't like it).
  * Added more commenting in spiroentrypoints.h to clarify functions.
  * Reconfigured code to avoid exporting bezctx_intf.h since this is
    supposed to be internal to libspiro and not for external calling.
  * Also added https://gcc.gnu.org/wiki/Visibility to reduce exports.
  * SPIRO_INTERNAL_BEZCTX and call-test21.c added for simpler method
    of accessing libspiro for programs that only need the end result.
  * Test added for 'a','h' to ensure points don't overlap, else exit.
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 20200505:
  * Bugfix for CVE-2019-19847 affecting {call-test14 to call-test19}.
  * Fix a memory access bug/error created earlier by patch 2017oct28
    Users using tagpoint libspiro20150702 are unaffected by this bug.
    Users using tagpoint libspiro20190731 are recommended to upgrade.
    Thanks to Frederic Cambus for calling attention to these faults.
  * Add optional 'end knot' for open curves (useful for displaying).
  * CRA Version also higher than so-bump 1.0.5 used on some distros;
    this maybe of interest to distros that bumped an earlier version.
  * Some garbage-in/garbage-out checks to verify we have 'ah' pairs,
    and we don't start with ']', or end with '['. Add libspiro.3 man.
  * Corrected set_di_to_x1y1() to use a constant bandwidth of 0.0005
  * Code improvements and bug fixes for better tagged/spiro results.
  * Several improvements added to further increase libspiro's speed.
* Thu Dec 19 2019 pgajdos@suse.com
- version update to 20190731
  * Scaling bug fixed. This allows libspiro to scale, and move spiro
    paths, therefore allowing users and/or programs the ability of
    using/making templates.
  * Additional spiro controls 'anchor' and 'handle' added.
  * Toggle switch ncq added, to allow further control of output results.
* Wed Dec 16 2015 pgajdos@suse.com
- update to version 0.5.20150702
  * Important bug fix issue #11 (missing file not included in 0v4).
  * 2 Minor bug fixes caught on Coverity scan, free() and if c=3.
  * Re-edit lib and tests to be more accommodating of older compilers.
  * Verify libspiro output data is correct for test curves {0,1,2,4}.
* Sat Feb 14 2015 p.drouand@gmail.com
- Update to version 0.3.20150131
  * fixes for LibSpiro package definitions (bfo#196780)
  * allowing other programs to seek LibSpiro using PKG_CHECK_MODULES().
    (bao#43373)
- Update home page and download source Urls
- Add autoconf, automake and libtool requirements; needed to generate
  the configure script
- Remove depreciated AUTHORS section
- Package AUTHORS, ChangeLog and COPYING into the doc directory
- gpl.txt is not provided anymore by upstream
* Mon Feb  6 2012 cfarrell@suse.com
- license update: GPL-2.0+
  See gpl.txt and e.g. spiro.c - there is no indication that this is
  BSD-3-Clause licensed and every indication that it is GPL-2.0+ licensed
* Sat Feb  4 2012 jengelh@medozas.de
- Restore ldconfig call for shlib package
* Sat Feb  4 2012 i@marguerite.su
- rename spec file and changelog to meet Factory requirements.
* Sat Feb  4 2012 jengelh@medozas.de
- Remove redundant tags/sections
- pkgconfig file: libm should not be in the shared link
- Remove pointless Obsoletes, the supposedly old name has never
  been in use before
* Sat Feb  4 2012 jengelh@medozas.de
- make license SPDX compatible.
* Sun Dec 25 2011 i@marguerite.su
- enable debuginfo package
* Sat Nov 26 2011 i@marguerite.su
- formated specfile to merge into home:opensuse_zh
